from enum import Enum


class Region(Enum):
    UNKNOWN = 0
    CN = 1
    US = 2
    SG = 3
    AIR = 4
    OTHER = 5
